pub trait WordKey: Copy {
// Required method
fn try_into_word(self) -> Result<Word, &'static str>;
}Expand description
A type that can be used as a key in a storage map.
Map keys are passed by value for lookups to avoid requiring Clone just to materialize a
Word for the host call.
Required Methods
Sourcefn try_into_word(self) -> Result<Word, &'static str>
fn try_into_word(self) -> Result<Word, &'static str>
Converts the key into the single storage word passed to the host.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".