pub trait WordValue: Sized {
// Required methods
fn try_into_word(self) -> Result<Word, &'static str>;
fn try_from_word(word: Word) -> Result<Self, &'static str>;
}Expand description
Required Methods
Sourcefn try_into_word(self) -> Result<Word, &'static str>
fn try_into_word(self) -> Result<Word, &'static str>
Converts the value into the single storage word used by the host.
Sourcefn try_from_word(word: Word) -> Result<Self, &'static str>
fn try_from_word(word: Word) -> Result<Self, &'static str>
Reconstructs the value from the single storage word returned by the host.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".